@@ -28,12 +28,6 @@ class DataCategory(SymEnum):
     long_genome = auto()
     freestyle = auto()
 
-class Platform(SymEnum):
-    """Simplified sequencing platform, mostly used if figuring out LibraryCategory"""
-    Illumina = auto()
-    PacBio = auto()
-    ONT = auto()
-
 class LibraryPrep(SymEnum):
     """Type of library prep"""
     CapTrap = auto()
@@ -41,6 +35,12 @@ class LibraryPrep(SymEnum):
     R2C2 = auto()
     cDNA = auto()
 
+class Platform(SymEnum):
+    """Simplified sequencing platform"""
+    Illumina = auto()
+    PacBio = auto()
+    ONT = auto()
+
 class Sample(SymEnum):
     """LRGASP sample identifier"""
     WTC11 = auto()
@@ -140,3 +140,18 @@ def is_simulation(sample):
 
 def challenge_desc(challenge_id):
     return f"Challenge {challenge_id.value} ({str(challenge_id)})"
+
+
+_short_platforms = frozenset([Platform.Illumina])
+_long_platforms = frozenset([Platform.PacBio, Platform.ONT])
+_data_category_platform_map = {
+    DataCategory.long_only: _long_platforms,
+    DataCategory.short_only: _short_platforms,
+    DataCategory.long_short: _short_platforms | _long_platforms,
+    DataCategory.long_genome: _long_platforms,
+    DataCategory.freestyle: _short_platforms | _long_platforms
+}
+
+def get_data_category_platforms(data_category):
+    "allowed platforms for a given data_category"
+    return _data_category_platform_map
