@@ -4,7 +4,7 @@ Experiment metadata parsing and validation.
 import os.path as osp
 import json
 from collections import defaultdict
-from lrgasp import LrgaspException, gopen, iter_to_str
+from lrgasp import LrgaspException, gopen, iter_to_str, existing_datafile_name
 from lrgasp.objDict import ObjDict
 from lrgasp.defs import Repository, Species, Challenge, DataCategory, Sample, LibraryPrep, Platform, EXPERIMENT_JSON
 from lrgasp.defs import validate_symbolic_ident, is_simulation, challenge_desc, get_challenge_samples
@@ -315,7 +315,7 @@ def get_models_gtf(experiment_md):
     """get path to models.gtf file or None if not valid for this experiment.
     Will not include .gz extension or check for existence."""
     if experiment_md.challenge_id in (Challenge.iso_detect_ref, Challenge.iso_quant):
-        return osp.join(experiment_md.experiment_dir, MODELS_GTF)
+        return existing_datafile_name(osp.join(experiment_md.experiment_dir, MODELS_GTF))
     else:
         return None
 
@@ -323,7 +323,7 @@ def get_read_model_map_tsv(experiment_md):
     """get path to read_model_map.gtf file or None if not valid for this
     experiment. Will not include .gz extension or check for existence."""
     if experiment_md.challenge_id in (Challenge.iso_detect_ref, Challenge.iso_detect_de_novo):
-        return osp.join(experiment_md.experiment_dir, READ_MODEL_MAP_TSV)
+        return existing_datafile_name(osp.join(experiment_md.experiment_dir, READ_MODEL_MAP_TSV))
     else:
         return None
 
@@ -331,7 +331,7 @@ def get_rna_fasta(experiment_md):
     """get path to RNA fasta file or None if not valid for this
     experiment. Will not include .gz extension or check for existence."""
     if experiment_md.challenge_id is Challenge.iso_detect_de_novo:
-        return osp.join(experiment_md.experiment_dir, DE_NOVO_RNA_FASTA)
+        return existing_datafile_name(osp.join(experiment_md.experiment_dir, DE_NOVO_RNA_FASTA))
     else:
         return None
 
@@ -339,6 +339,6 @@ def get_expression_tsv(experiment_md):
     """get path to expression TSV file or None if not valid for this
     experiment. Will not include .gz extension or check for existence."""
     if experiment_md.challenge_id is Challenge.iso_quant:
-        return osp.join(experiment_md.experiment_dir, EXPRESSION_TSV)
+        return existing_datafile_name(osp.join(experiment_md.experiment_dir, EXPRESSION_TSV))
     else:
         return None
